'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var data = require('./data.js');

function getFontStyle(font, fontStyle) {
    switch (fontStyle) {
        case 'italic':
            return font?.hasItalic ? 'italic' : null;
        case 'normal':
            return 'normal';
        case null:
        default:
            return null;
    }
}
const fs = (category) => (level, { lineHeight, fontWeight, fontStyle, unit }) => {
    const fontFamilyValue = data.fontMapping[category];
    const fontSizeValue = unit === 'px'
        ? Number(data.fontSizeMapping[category][level])
        : // @ts-expect-error -- the types actually overlap, see https://gist.github.com/mxdvl/5e31fd5b13670b6a41ddac6c65efeee4
            `${Number(data.remFontSizeMapping[category][level])}rem`;
    const lineHeightValue = unit === 'px'
        ? // line-height is defined as a unitless value, so we multiply
            // by the element's font-size in px to get the px value
            `${data.lineHeightMapping[lineHeight] *
                Number(data.fontSizeMapping[category][level])}px`
        : data.lineHeightMapping[lineHeight];
    // TODO: consider logging an error in development if a requested
    // font is unavailable
    const requestedFont = data.availableFonts[category][fontWeight];
    const fontWeightValue = requestedFont
        ? data.fontWeightMapping[fontWeight]
        : '';
    const fontStyleValue = getFontStyle(requestedFont, fontStyle);
    return Object.assign({
        fontFamily: fontFamilyValue,
        fontSize: fontSizeValue,
        lineHeight: lineHeightValue,
    }, fontWeightValue ? { fontWeight: fontWeightValue } : {}, fontStyleValue ? { fontStyle: fontStyleValue } : {});
};

exports.fs = fs;
//# sourceMappingURL=fs.js.map
