import { bodySizes, fontMapping, fontWeightMapping, headlineSizes, lineHeightMapping, remBodySizes, remHeadlineSizes, remTextSansSizes, remTitlepieceSizes, textSansSizes, titlepieceSizes } from "./data";
import { BodySizes, Category, FontScaleFunctionStr, FontStyle, FontWeight, FontWeightDefinition, HeadlineSizes, LineHeight, ScaleUnit, TextSansSizes, TitlepieceSizes } from "../types-fce00180";
type TypographyApi<Sizes> = {
    [key in keyof Sizes]: FontScaleFunctionStr;
};
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/packages-source-foundations-typography--page#titlepiece) •
 * [Design System](https://theguardian.design/2a1e5182b/p/602314-typography/t/358767)
 *
 * ```
 * font-family: 'GT Guardian Titlepiece';
 * ```
 */
declare const titlepiece: TypographyApi<TitlepieceSizes>;
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/packages-source-foundations-typography--page#headline) •
 * [Design System](https://theguardian.design/2a1e5182b/p/602314-typography/t/7310bd)
 *
 * ```
 * font-family: 'GH Guardian Headline';
 * ```
 */
declare const headline: TypographyApi<HeadlineSizes>;
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/packages-source-foundations-typography--page#body) •
 * [Design System](https://theguardian.design/2a1e5182b/p/602314-typography/t/88cd8e)
 *
 * ```
 * font-family: 'GuardianTextEgyptian';
 * ```
 */
declare const body: TypographyApi<BodySizes>;
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/packages-source-foundations-typography--page#text-sans) •
 * [Design System](https://theguardian.design/2a1e5182b/p/602314-typography/t/076605)
 *
 * ```
 * font-family: 'GuardianTextSans';
 * ```
 */
declare const textSans: TypographyApi<TextSansSizes>;
export { titlepiece, headline, body, textSans, titlepieceSizes, headlineSizes, bodySizes, textSansSizes, remTitlepieceSizes, remHeadlineSizes, remBodySizes, remTextSansSizes, fontMapping, fontWeightMapping, lineHeightMapping };
export type { ScaleUnit, Category, LineHeight, FontWeight, FontStyle, FontWeightDefinition };
